Credits — SnapPy 3.3.2 documentation

# Credits

Primary development and maintenance:

- Marc Culler

- Nathan Dunfield

- Matthias Goerner

- Jeff Weeks

Additional contributions:

- Mark Bell, Tracy Hall, Saul Schleimer, Twister.

- Jim Hoste and Morwen Thistlethwaite, manifold and link censuses.

- Ben Burton, manifold censuses and isosig code.

- Abhijit Champanerkar and Ilya Kofman, knot censuses.

- Robert Lipschitz and Jennet Dickinson, improvements to Spherogram.

- Malik Obeidin, improvements to Spherogram and the manifold databases.

- Malik Obeidin and Cameron Rudd, exterior to link diagram code.

- Jose Sanchez, 3D printing code.

- Jean-Philippe Burelle, SL(2, C) character variety code.

- David Bachman, Henry Segerman and Saul Schleimer, initial code the raytraced inside view is based on.

- Zoltán Szabó, computing the knot Floer homology calculator.

- PARI library.

- QD quad-double library.

- Frédéric Chapoton, code cleanup and linting.

- Sherry Gong for code related to ribbon concordances and slice obstrutions [DG].

- Shana Li for the census of 10 tetrahedra cusped manfiolds [Li].

- Others, please let Marc or Nathan know if we’ve forgotten you.

## Citing SnapPy

Please cite as:

M. Culler, N. M. Dunfield, M. Goerner, and J. R. Weeks, SnapPy, a computer program for studying the geometry and topology of 3-manifolds, http://snappy.computop.org

or in BibTeX format

    @misc{SnapPy,
         author={Culler, Marc and Dunfield, Nathan M. and Goerner,
         Matthias and Weeks, Jeffrey R.},
         title={Snap{P}y, a computer program for studying the geometry and topology of $3$-manifolds},
         howpublished={Available at \url{http://snappy.computop.org} (DD/MM/YYYY)},
    }

or as an AMSRef:

    \bib{SnapPy}{misc}{
         author={Culler, Marc},
         author={Dunfield, Nathan M.},
         author={Goerner, Matthias},
         author={Weeks, Jeffrey R.},
         title={Snap{P}y, a computer program for studying the geometry and topology of $3$-manifolds},
         note={Available at \url{http://snappy.computop.org} (DD/MM/YYYY)}
    }

where DD/MM/YYYY should be replaced by the date when you downloaded your copy of SnapPy.